@@ -1,67 +1,70 @@
 var languageNames = {
 "en-US": "Angielski (USA)",
+"sq": "Albański",
 "am": "Amharski",
 "ar": "Arabski",
 "ast": "Asturyjski",
-"bg": "Bułgarski",
 "bn": "Bengalski",
 "bn-IN": "Bengalski (Indie)",
-"bo": "Tybetański",
 "bs": "Bośniacki",
+"bg": "Bułgarski",
 "ca": "Kataloński",
 "ca-valencia": "Walencki kataloński",
+"zh-CN": "Chiński (uproszczony)",
+"zh-TW": "Chiński (tradycyjny)",
+"hr": "Chorwacki",
 "cs": "Czeski",
 "da": "Duński",
-"de": "niemiecki",
+"nl": "Holenderski",
 "dz": "Dzongkha",
-"el": "Grecki",
 "en-GB": "Angielski (UK)",
 "en-ZA": "Angielski (RPA)",
 "eo": "Esperanto",
-"es": "Hszpański",
 "et": "Estoński",
 "eu": "Baskijski",
 "fi": "Fiński",
 "fr": "Francuski",
 "gl": "Galicyjski",
+"ka": "Gruziński",
+"de": "Niemiecki",
+"el": "Grecki",
 "gu": "Gudżarati",
 "he": "Hebrajski",
 "hi": "Hinduski",
-"hr": "Chorwacki",
 "hu": "Węgierski",
 "id": "Indonezyjski",
 "is": "Islandzki",
 "it": "Włoski",
 "ja": "Japoński",
-"ka": "Gruziński",
 "km": "Khmerski",
 "ko": "Koreański",
 "lo": "Laotański",
-"lt": "Litewski",
 "lv": "Łotewski",
+"lt": "Litewski",
 "mk": "Macedoński",
-"nb": "Norweski (bokmål)",
 "ne": "Nepalski",
-"nl": "Holenderski",
 "nn": "Norweski (nynorsk)‎",
+"nb": "Norweski (bokmål)",
 "om": "Oromo",
 "pl": "Polski",
 "pt": "Portugalski",
-"pt-BR": "Portugalski brazylijski",
+"pt-BR": "Portugalski (Brazylia)",
 "ro": "Rumuński",
 "ru": "Rosyjski",
-"si": "Sinhala",
 "sid": "Sidama",
+"si": "Sinhala",
 "sk": "Słowacki",
 "sl": "Słoweński",
-"sq": "Albański",
+"dsb": "Łużycki (dolny)",
+"hsb": "Łużycki (górny)",
+"es": "Hszpański",
 "sv": "Szwedzki",
-"ta": "Tamilski",
 "tg": "Tadżycki",
+"ta": "Tamilski",
+"bo": "Tybetański",
+"tl": "Tagalog",
 "tr": "Turecki",
 "ug": "Ujgurski",
 "uk": "Ukraiński",
 "vi": "Wietnamski",
-"zh-CN": "Chiński (uproszczony)",
-"zh-TW": "Chiński (tradycyjny)",
 };
